emoji\_data package
===================

Submodules
----------

emoji\_data.emoji\_data module
------------------------------

.. automodule:: emoji_data.emoji_data
    :members:
    :undoc-members:
    :show-inheritance:

emoji\_data.version module
--------------------------

.. automodule:: emoji_data.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: emoji_data
    :members:
    :undoc-members:
    :show-inheritance:
